==> jc-1.4.0.tar.gz: javax/swing/plaf/TabbedPaneUI.h <==
// public abstract class javax.swing.plaf.TabbedPaneUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class fa2715c628621159 javax_swing_plaf_TabbedPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_TabbedPaneUI_H_
#define _JC_javax_swing_plaf_TabbedPaneUI_H_

// Forward structure declarations
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JTabbedPane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$sub_refs	_jc_javax_swing_plaf_TabbedPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs	_jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$refs	_jc_javax_swing_plaf_TabbedPaneUI$refs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$nonrefs	_jc_javax_swing_plaf_TabbedPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$object	_jc_javax_swing_plaf_TabbedPaneUI$object;

typedef const struct _jc_javax_swing_plaf_TabbedPaneUI$vmethods	_jc_javax_swing_plaf_TabbedPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_TabbedPaneUI$vtable	_jc_javax_swing_plaf_TabbedPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_TabbedPaneUI$vtype	_jc_javax_swing_plaf_TabbedPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_TabbedPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *);

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_plaf_TabbedPaneUI$method$getTabBounds$2c898c9752835959(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint);
extern jint _jc_javax_swing_plaf_TabbedPaneUI$method$getTabRunCount$072d1ddd70077ab8(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *);
extern jint _jc_javax_swing_plaf_TabbedPaneUI$method$tabForCoordinate$3da4a735add8df2e(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_TabbedPaneUI$method_info$getTabBounds$2c898c9752835959;
extern _jc_method _jc_javax_swing_plaf_TabbedPaneUI$method_info$getTabRunCount$072d1ddd70077ab8;
extern _jc_method _jc_javax_swing_plaf_TabbedPaneUI$method_info$tabForCoordinate$3da4a735add8df2e;

// Virtual methods structure
struct _jc_javax_swing_plaf_TabbedPaneUI$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getTabBounds$2c898c9752835959)(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint);
	jint	(*getTabRunCount$072d1ddd70077ab8)(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *);
	jint	(*tabForCoordinate$3da4a735add8df2e)(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_TabbedPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TabbedPaneUI$vmethods	javax_swing_plaf_TabbedPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_TabbedPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_TabbedPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_TabbedPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_TabbedPaneUI$refs {
    _jc_javax_swing_plaf_TabbedPaneUI$sub_refs	javax_swing_plaf_TabbedPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_TabbedPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs	javax_swing_plaf_TabbedPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_TabbedPaneUI$object {
	_jc_javax_swing_plaf_TabbedPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_TabbedPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_TabbedPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_TabbedPaneUI$vtype _jc_javax_swing_plaf_TabbedPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_TabbedPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_TabbedPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_TabbedPaneUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/TabbedPaneUI.h <==
// public abstract class javax.swing.plaf.TabbedPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class fa2715c628621159 javax_swing_plaf_TabbedPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_TabbedPaneUI_H_
#define _JC_javax_swing_plaf_TabbedPaneUI_H_

// Forward structure declarations
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JTabbedPane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$sub_refs	_jc_javax_swing_plaf_TabbedPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs	_jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$refs	_jc_javax_swing_plaf_TabbedPaneUI$refs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$nonrefs	_jc_javax_swing_plaf_TabbedPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_TabbedPaneUI$object	_jc_javax_swing_plaf_TabbedPaneUI$object;

typedef const struct _jc_javax_swing_plaf_TabbedPaneUI$vmethods	_jc_javax_swing_plaf_TabbedPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_TabbedPaneUI$vtable	_jc_javax_swing_plaf_TabbedPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_TabbedPaneUI$vtype	_jc_javax_swing_plaf_TabbedPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_TabbedPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_plaf_TabbedPaneUI$method$getTabBounds$2c898c9752835959(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_TabbedPaneUI$method$getTabRunCount$072d1ddd70077ab8(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_TabbedPaneUI$method$tabForCoordinate$3da4a735add8df2e(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_TabbedPaneUI$method_info$getTabBounds$2c898c9752835959;
extern _jc_method _jc_javax_swing_plaf_TabbedPaneUI$method_info$getTabRunCount$072d1ddd70077ab8;
extern _jc_method _jc_javax_swing_plaf_TabbedPaneUI$method_info$tabForCoordinate$3da4a735add8df2e;

// Virtual methods structure
struct _jc_javax_swing_plaf_TabbedPaneUI$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getTabBounds$2c898c9752835959)(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint) _JC_JCNI_ATTR;
	jint	(*getTabRunCount$072d1ddd70077ab8)(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *) _JC_JCNI_ATTR;
	jint	(*tabForCoordinate$3da4a735add8df2e)(_jc_env *, struct _jc_javax_swing_plaf_TabbedPaneUI$object *, struct _jc_javax_swing_JTabbedPane$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_TabbedPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TabbedPaneUI$vmethods	javax_swing_plaf_TabbedPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_TabbedPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_TabbedPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_TabbedPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_TabbedPaneUI$refs {
    _jc_javax_swing_plaf_TabbedPaneUI$sub_refs	javax_swing_plaf_TabbedPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_TabbedPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TabbedPaneUI$sub_nonrefs	javax_swing_plaf_TabbedPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_TabbedPaneUI$object {
	_jc_javax_swing_plaf_TabbedPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_TabbedPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_TabbedPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_TabbedPaneUI$vtype _jc_javax_swing_plaf_TabbedPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_TabbedPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_TabbedPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_TabbedPaneUI_H_ */
